@@ -1,6 +1,6 @@
 /*
  * iostat: report CPU and I/O statistics
- * (C) 1998-2007 by Sebastien GODARD (sysstat <at> wanadoo.fr)
+ * (C) 1998-2007 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -45,6 +45,8 @@
 #define _(string) (string)
 #endif
 
+#define SCCSID "@(#)" __FILE__ " compiled " __DATE__ " " __TIME__
+char *sccsid(void) { return (SCCSID); }
 
 struct comm_stats  comm_stats[2];
 struct io_stats *st_iodev[2];
@@ -52,7 +54,6 @@ struct io_nfs_stats *st_ionfs[2];
 struct io_hdr_stats *st_hdr_iodev, *st_hdr_ionfs;
 struct io_dlist *st_dev_list;
 
-
 int iodev_nr = 0;	/* Nb of devices and partitions found */
 int ionfs_nr = 0;	/* Nb of NFS mounted directories found */
 int cpu_nr = 0;		/* Nb of processors on the machine */
@@ -580,7 +581,8 @@ void read_sysfs_dlist_part_stat(int curr, char *dev_name)
    struct dirent *drd;
    char dfile[MAX_PF_NAME], filename[MAX_PF_NAME];
 
-   sprintf(dfile, "%s/%s", SYSFS_BLOCK, dev_name);
+   snprintf(dfile, MAX_PF_NAME, "%s/%s", SYSFS_BLOCK, dev_name);
+   dfile[MAX_PF_NAME - 1] = '\0';
 
    /* Open current device directory in /sys/block */
    if ((dir = opendir(dfile)) == NULL)
@@ -590,7 +592,8 @@ void read_sysfs_dlist_part_stat(int curr, char *dev_name)
    while ((drd = readdir(dir)) != NULL) {
       if (!strcmp(drd->d_name, ".") || !strcmp(drd->d_name, ".."))
 	 continue;
-      sprintf(filename, "%s/%s/%s", dfile, drd->d_name, S_STAT);
+      snprintf(filename, MAX_PF_NAME, "%s/%s/%s", dfile, drd->d_name, S_STAT);
+      filename[MAX_PF_NAME - 1] = '\0';
 
       /* Read current partition stats */
       read_sysfs_file_stat(curr, filename, drd->d_name, DT_PARTITION);
@@ -618,8 +621,9 @@ void read_sysfs_dlist_stat(int curr, int flags)
 
    for (dev = 0; dev < dlist_idx; dev++) {
       st_dev_list_i = st_dev_list + dev;
-      sprintf(filename, "%s/%s/%s",
+      snprintf(filename, MAX_PF_NAME, "%s/%s/%s",
 	      SYSFS_BLOCK, st_dev_list_i->dev_name, S_STAT);
+      filename[MAX_PF_NAME - 1] = '\0';
 
       /* Read device stats */
       ok = read_sysfs_file_stat(curr, filename, st_dev_list_i->dev_name, DT_DEVICE);
@@ -657,7 +661,8 @@ void read_sysfs_stat(int curr, int flags)
       while ((drd = readdir(dir)) != NULL) {
 	 if (!strcmp(drd->d_name, ".") || !strcmp(drd->d_name, ".."))
 	    continue;
-	 sprintf(filename, "%s/%s/%s", SYSFS_BLOCK, drd->d_name, S_STAT);
+	 snprintf(filename, MAX_PF_NAME, "%s/%s/%s", SYSFS_BLOCK, drd->d_name, S_STAT);
+	 filename[MAX_PF_NAME - 1] = '\0';
 	
 	 /* If current entry is a directory, try to read its stat file */
 	 ok = read_sysfs_file_stat(curr, filename, drd->d_name, DT_DEVICE);
@@ -1360,9 +1365,9 @@ int main(int argc, char **argv)
 	       break;
 	
 	     case 'N':
-	       flags |= I_D_DEVMAP_NAME;	/* Display device mapper logical name */
+	       flags |= I_D_DEVMAP_NAME; /* Display device mapper logical name */
 	       break;
-	       
+	
 	     case 'n':
 	       flags |= I_D_NFS;	/* Display NFS stats */
 	       break;
