@@ -1,6 +1,6 @@
 /*
  * sar and sadf common routines.
- * (C) 1999-2007 by Sebastien GODARD (sysstat <at> wanadoo.fr)
+ * (C) 1999-2007 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -668,6 +668,9 @@ int parse_sar_opt(char *argv[], int opt, unsigned int *actflag,
        case 'b':
 	 *actflag |= A_IO;
 	 break;
+       case 'C':
+	 *flags |= S_F_COMMENT;
+	 break;
        case 'c':
 	 *actflag |= A_PROC;
 	 break;
